Oracle-DAO project
=======================

Módulo para criar uma camada de conexao a banco de dados Oracle, com padrão Singleton
e prover interface para métodos basicos de DML, Select e chamada a Procedures/Funçõess
Pre-requisito: cx_Oracle
Compatível com Python 3.

----
Changelog
0.1.1 - Incluído nos parâmetros de conexão o enconding UTF-8

#todo: include a module's overview and basic usage examples.
